@@ -14,17 +14,15 @@ class Sale:
         domain=[('company', '=', Eval('company'))],
         states={
             'readonly': Or(Not(Equal(Eval('state'), 'draft')),
-                Bool(Eval('lines'))),
+                Bool(Eval('lines', [0]))),
             },
-        depends=['state', 'company', 'lines'])
+        depends=['state', 'company'])
 
     @classmethod
     def __setup__(cls):
         super(Sale, cls).__setup__()
         cls.party.states['readonly'] = (cls.party.states['readonly']
-            | Eval('lines'))
-        if 'lines' not in cls.party.depends:
-            cls.party.depends.append('lines')
+            | Eval('lines', [0]))
         cls.lines.states['readonly'] = (cls.lines.states['readonly']
             | ~Eval('party'))
         if 'party' not in cls.lines.depends:
@@ -45,12 +43,9 @@ class SaleLine:
     @classmethod
     def __setup__(cls):
         super(SaleLine, cls).__setup__()
-        if '_parent_sale.price_list' not in cls.quantity.on_change:
-            cls.quantity.on_change.append('_parent_sale.price_list')
-        if '_parent_sale.price_list' not in cls.unit.on_change:
-            cls.unit.on_change.append('_parent_sale.price_list')
-        if '_parent_sale.price_list' not in cls.product.on_change:
-            cls.product.on_change.append('_parent_sale.price_list')
+        cls.quantity.on_change.add('_parent_sale.price_list')
+        cls.unit.on_change.add('_parent_sale.price_list')
+        cls.product.on_change.add('_parent_sale.price_list')
 
     def _get_context_sale_price(self):
         context = super(SaleLine, self)._get_context_sale_price()
